RandomState

Type Alias RandomState 

pub type RandomState = RandomState<AVALANCHE, SPONGE, COMPACT, PROTECTED>;
A rapidhash equivalent to [std::hash::RandomState] that uses a random seed and secrets for minimal DoS resistance.

This initializes a crate::quality::RapidHasher with the following settings:

  • AVALANCHE is disabled.
  • SPONGE is enabled.
  • COMPACT is disabled.
  • PROTECTED is disabled.

Use crate::quality::RandomState for a higher quality but slower hash output where desirable.

Aliased Type

pub struct RandomState { /* private fields */ }