RandomState

Type Alias RandomState 

pub type RandomState = RandomState<AVALANCHE, SPONGE, COMPACT, PROTECTED>;
A rapidhash equivalent to [std::hash::RandomState] that uses a random seed and secrets for minimal DoS resistance.

This initializes a RapidHasher with the following settings:

  • AVALANCHE is enabled.
  • SPONGE is enabled.
  • COMPACT is disabled.
  • PROTECTED is disabled.

Use crate::fast::RandomState for a lower quality but faster hash output where desirable.

Aliased Type

pub struct RandomState { /* private fields */ }