RapidRng

Struct RapidRng 

pub struct RapidRng { /* private fields */ }
๐Ÿ‘ŽDeprecated since 4.5.0:

use the rapidrand crate instead

A random number generator that uses the rapidhash mixing algorithm.

This deterministic RNG is optimized for speed and throughput. This is not a cryptographic random number generator.

This RNG is compatible with [rand_core::RngCore] and [rand_core::SeedableRng].

Example

use rapidhash::rng::RapidRng;

let mut rng = RapidRng::default();
println!("{}", rng.next());

Implementations

Source

impl RapidRng

pub fn new(seed: u64) -> Self

Create a new random number generator from a specified seed.

Also see RapidRng::default() with the std feature enabled for seed randomisation based on the current time.

pub fn state(&self) -> [u8; 8]

Export the current state of the random number generator.

pub fn next(&mut self) -> u64

Get the next random number from this PRNG and iterate the state.