pub const fn rapidhash_v3(data: &[u8]) -> u64Expand description
Rapidhash V3 a single byte stream, matching the C++ implementation, with the default seed.
Fixed length inputs will greatly benefit from inlining with rapidhash_v3_inline instead.
pub const fn rapidhash_v3(data: &[u8]) -> u64Rapidhash V3 a single byte stream, matching the C++ implementation, with the default seed.
Fixed length inputs will greatly benefit from inlining with rapidhash_v3_inline instead.