GlobalState

Struct GlobalState 

pub struct GlobalState<const AVALANCHE: bool, const SPONGE: bool, const COMPACT: bool, const PROTECTED: bool> { /* private fields */ }
A BuildHasher that uses a global seed and secrets, randomized only once on startup.

The global secrets are randomized on the first instantiation, and then every subsequent instance of GlobalState will re-use the same seed and secrets, ensuring consistent hash outputs for the duration of the program.

Implementations

Source

impl<const AVALANCHE: bool, const SPONGE: bool, const COMPACT: bool, const PROTECTED: bool> GlobalState<AVALANCHE, SPONGE, COMPACT, PROTECTED>

pub fn new() -> Self

Create a new global state with a global seed and secrets.

The seed and secrets will be randomized on the first instantiation of GlobalState, but all subsequent instances will share the same seed and secrets.

On platforms which do not support atomic pointers, the secrets will be the default rapidhash secrets, which are not randomized. Therefore, targets without atomic pointer support will not have minimal HashDoS resistance guarantees.