RandomState

Struct RandomState 

pub struct RandomState<const AVALANCHE: bool, const SPONGE: bool, const COMPACT: bool, const PROTECTED: bool> { /* private fields */ }
A [std::hash::RandomState] compatible hasher that initializes a RapidHasher with a random seed and random global secrets.

This is designed to provide some HashDoS resistance by using a random seed per hashmap, and a global random set of secrets.

Portability

On most target platforms, the secrets are randomly initialized once and cached globally for the lifetime of the program using a mix of ASLR and other entropy sources. The seed is randomly initialized for each new instance of RandomState using only ASLR and a mixing step.

On targets without atomic pointer support, the global secrets will not be randomized, and instead will fall back to the default secrets. This means these platforms will not have minimal HashDoS resistance guarantees. If this is important for your application, please raise a GitHub issue to improve support for these platforms.

Example

use std::collections::HashMap;
use std::hash::Hasher;

use rapidhash::quality::RandomState;

let mut map = HashMap::with_hasher(RandomState::default());
map.insert(42, "the answer");

Implementations

Source

impl<const AVALANCHE: bool, const SPONGE: bool, const COMPACT: bool, const PROTECTED: bool> RandomState<AVALANCHE, SPONGE, COMPACT, PROTECTED>

pub fn new() -> Self

Create a new random state with a random seed.

The seed is always randomized by using ASLR on every new instance of RandomState.

With the rand feature enabled, the secrets will be randomized using [rand::random]. Otherwise, a mix of ASLR and some other poorer sources of entropy will be mixed together to generate the secrets. The secrets are statically cached for the lifetime of the program after their initial generation.

On platforms that do not support atomic pointers, the secrets will be the default rapidhash secrets, which are not randomized. Therefore, targets without atomic pointer support will not have minimal HashDoS resistance guarantees.