pub struct RapidHasher<'s, const AVALANCHE: bool, const SPONGE: bool, const COMPACT: bool = false, const PROTECTED: bool = false> { /* private fields */ }Expand description
A Hasher trait compatible hasher that uses the rapidhash
algorithm, and uses #[inline(always)] for all methods.
Using #[inline(always)] can deliver a large performance improvement when hashing complex
objects, but should be benchmarked for your specific use case. If you have HashMaps for many
different types this may come at the cost of some binary size increase.
See crate::fast::RandomState for usage with [std::collections::HashMap].
Example
use std::hash::Hasher;
use rapidhash::quality::RapidHasher;
let mut hasher = RapidHasher::default();
hasher.write(b"hello world");
let hash = hasher.finish();Implementations
Sourceimpl<'s, const AVALANCHE: bool, const SPONGE: bool, const COMPACT: bool, const PROTECTED: bool> RapidHasher<'s, AVALANCHE, SPONGE, COMPACT, PROTECTED>
impl<'s, const AVALANCHE: bool, const SPONGE: bool, const COMPACT: bool, const PROTECTED: bool> RapidHasher<'s, AVALANCHE, SPONGE, COMPACT, PROTECTED>
Sourcepub const DEFAULT_SEED: u64 = super::seed::DEFAULT_SEED
pub const DEFAULT_SEED: u64 = super::seed::DEFAULT_SEED
Default RapidHasher seed.
Sourcepub const fn new(seed: u64) -> Self
pub const fn new(seed: u64) -> Self
Create a new RapidHasher with a custom seed.
See instead crate::quality::RandomState::new or crate::fast::RandomState::new for a random seed and random secret initialization, for minimal DoS resistance.
Sourcepub const fn default_const() -> Self
pub const fn default_const() -> Self
Create a new RapidHasher using the default seed and secrets.